@@ -16,8 +16,8 @@
 
 #include <KDirNotify>
 #include <KPluginFactory>
-#include <Solid/GenericInterface>
 #include <Solid/DeviceNotifier>
+#include <Solid/GenericInterface>
 
 #include "daemonadaptor.h"
 #include "kiod_kmtpd_debug.h"
@@ -44,8 +44,6 @@ KMTPd::KMTPd(QObject *parent, const QList<QVariant> &parameters)
     connect(notifier, &Solid::DeviceNotifier::deviceRemoved, this, &KMTPd::deviceRemoved);
 
     new DaemonAdaptor(this);
-    QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.kiod5"));
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/modules/kmtpd"), this);
 }
 
 KMTPd::~KMTPd()
@@ -117,8 +115,7 @@ void KMTPd::checkDevice(const Solid::Device &solidDevice)
                     }
                 }
             }
-        }
-        break;
+        } break;
         case LIBMTP_ERROR_GENERAL:
         default:
             qCWarning(LOG_KIOD_KMTPD) << "Unknown connection error";
@@ -130,7 +127,7 @@ void KMTPd::checkDevice(const Solid::Device &solidDevice)
 
 MTPDevice *KMTPd::deviceFromUdi(const QString &udi) const
 {
-    auto deviceIt = std::find_if(m_devices.constBegin(), m_devices.constEnd(), [udi] (const MTPDevice *device) {
+    auto deviceIt = std::find_if(m_devices.constBegin(), m_devices.constEnd(), [udi](const MTPDevice *device) {
         return device->udi() == udi;
     });
 
